@@ -12,6 +12,7 @@ from resources.benchmark_resource import BenchmarkResource
 from resources.oakgate_resource import OakgateResource
 from resources.stop_flag_resource import StopFlagResource
 from resources.git_resource import GitResource
+from resources.upgrade_resource import UpgradeResource
 
 
 class RestClient(object):
@@ -26,3 +27,4 @@ class RestClient(object):
         self.oakgate = OakgateResource(host, port, __session, time_out)
         self.stop_flag = StopFlagResource(host, port, __session, time_out)
         self.git = GitResource(host, port, __session, time_out)
+        self.upgrade = UpgradeResource(host, port, __session, time_out)
